package yatzy;

import java.util.ArrayList;
import java.util.List;

/**
 * Game Options
 * This should be used in a *very* disciplined manner
 * The only writes (i.e call to set-methods) should be
 * from the OptionsDialog.
 * 
 * @author hajo
 */
public class YatzyOptions {

    private YatzyOptions(){      
    }
    
    // Defaults and options for game
    public static final int MAX_DICE = 5; // Number of die
    public static final int MAX_ROLL = 3;  // Player may roll 3 times
    public static int MAX_PLAYERS = 6;  // Max 6 players
    private static int maxDice = MAX_DICE;  // Set default value
    private static int maxRolls = MAX_ROLL;  // Set default value
    // User options
    private static boolean robot = false;  // See RobobYatzy
    private static List<Player> players = new ArrayList<>();  // The players
   
    public static List<Player> getPlayers() {
        // Some default players
        if (players.isEmpty()) {
            players.add(new Player("Anna", 0));
            players.add(new Player("Urban", 1));
        }
        return players;

    }

    public static void setPlayers(List<Player> players) {
        YatzyOptions.players = players;
    }

    public static void setRobot(boolean b) {
        robot = b;
    }

    public static boolean useRobot() {
        return robot;
    }

    public static int getMaxDice() {
        return maxDice;
    }

    public static void setMaxDice(int maxDice) {
        YatzyOptions.maxDice = maxDice;
    }

    public static int getMaxRolls() {
        return maxRolls;
    }

    public static void setMaxRolls(int maxRolls) {
        YatzyOptions.maxRolls = maxRolls;
    }
}
