package yatzy.gui;

import java.awt.BorderLayout;
import java.awt.CheckboxMenuItem;
import java.awt.Font;
import java.awt.Menu;
import java.awt.MenuBar;
import java.awt.MenuItem;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.net.URL;
import java.util.List;
import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import yatzy.Player;
import yatzy.YatzyOptions;
//import yatzy.RobotYatzy;
import yatzy.StandardYatzy;
import yatzy.Yatzy;
import yatzy.io.IYatzyReader;
import yatzy.io.YatzyReaderFactory;

/**
 * Application main window
 *
 * @author hajo
 */
public class MainFrame extends JFrame implements ActionListener {

    private Menu options;
    private boolean isRunning = false;
    private MenuItem start;
    private JLabel background;
    private Yatzy yatzy;
    private Font actualFont = GUIOptions.getPlainFont();

    public MainFrame() {
        this.setLocationRelativeTo(null);
        this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        this.setLayout(new BorderLayout());
        this.setTitle("YATZY");
        this.createMenu();
        URL imgURL = getClass().getResource("/yatzy/gui/yatzy.jpg");
        ImageIcon ii = new ImageIcon(imgURL, "splash");
        background = new JLabel(ii, JLabel.CENTER);
        this.add(background, BorderLayout.CENTER);
        pack();
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        switch (e.getActionCommand()) {
            case "start":
                if (isRunning) {
                    int action = JOptionPane.showConfirmDialog(this,
                            "Restart will wipe all!",
                            "Restart", JOptionPane.YES_NO_OPTION);
                    if (action == JOptionPane.OK_OPTION) {
                        start();
                    }
                } else {
                    start();
                }
                break;
            case "exit":
                int action = JOptionPane.showConfirmDialog(this,
                        "Really Exit?",
                        "Exit", JOptionPane.YES_NO_OPTION);
                if (action == JOptionPane.OK_OPTION) {
                    isRunning = false;
                    System.exit(0);
                }
                break;
            case "save":
                save();
                break;
            case "open":
                open();
                break;
            case "players":
                new PlayersDialog(this).setVisible(true);
                break;
            default:
                ;
        }
    }

    private void start() {
        JPanel score;

        yatzy = new StandardYatzy(YatzyOptions.getPlayers(),
                YatzyOptions.getMaxDice(), YatzyOptions.getMaxRolls());
        score = new StandardScorePanel(yatzy);


        isRunning = true;
        options.setEnabled(false);
        this.remove(background);

        DicePanel dice = new DicePanel(yatzy);
        ButtonPanel button = new ButtonPanel(yatzy);
        
        JPanel mainPanel = new JPanel();
        mainPanel.setLayout(new BorderLayout());
        mainPanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
        mainPanel.add(button, BorderLayout.NORTH);
        mainPanel.add(score, BorderLayout.CENTER);
        mainPanel.add(dice, BorderLayout.SOUTH);

        // Finally add complete GUI to Frame
        this.add(mainPanel, BorderLayout.CENTER);
        this.pack();
        
        yatzy.start();
    }

    private void createMenu() {
        // File
        start = new MenuItem("Start");
        start.setActionCommand("start");
        start.addActionListener(this);

        MenuItem save = new MenuItem("Save");
        save.setActionCommand("save");
        save.addActionListener(this);

        MenuItem open = new MenuItem("Open");
        open.setActionCommand("open");
        open.addActionListener(this);

        MenuItem exit = new MenuItem("Exit");
        exit.setActionCommand("exit");
        exit.addActionListener(this);

        Menu file = new Menu("File");
        file.add(start);
        file.addSeparator();
        file.add(save);
        file.add(open);
        file.addSeparator();
        file.add(exit);

        // View
        CheckboxMenuItem bigfont = new CheckboxMenuItem("Big font");
        //bigfont.addItemListener(this);
        Menu view = new Menu("View");
        view.add(bigfont);
        
        // Options
        MenuItem players = new MenuItem("Players");
        players.setActionCommand("players");
        players.addActionListener(this);
        options = new Menu("Options");
        options.add(players);

        MenuBar bar = new MenuBar();
        bar.add(file);
        bar.add(view);
        bar.add(options);
        this.setMenuBar(bar);
    }

    // Used to save current state of game to file
    private void save() {
        if (!isRunning) {
            return;
        }
        final JFileChooser save = new JFileChooser();
        save.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
        int returnVal = save.showSaveDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION) {
            File file = save.getSelectedFile();
            System.out.println(file.getAbsoluteFile());
            IYatzyReader r = YatzyReaderFactory.getReader();
            r.save(file.getAbsoluteFile().toString(), yatzy.getPlayers());
        }
    }

    // Used to restore a previously saved game (and end current)
    private void open() {
        final JFileChooser open = new JFileChooser();
        int returnVal = open.showOpenDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION) {
            File file = open.getSelectedFile();
            IYatzyReader r = YatzyReaderFactory.getReader();
            List<Player> ps = r.open(file.getAbsoluteFile().toString());
            YatzyOptions.setPlayers(ps);
        }
    }
}
